<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>关于...</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>信息(&amp;I)</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>翻译(&amp;T)</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>许可证(&amp;L)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>SMPlayer 的 YouTube%1 查看器</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>版本: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>便携版</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>使用Qt %1 (%2) 编译</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our website for updates:</source>
        <translation>访问我们的网站获取更新：</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="87"/>
        <source>Many people contributed with translations.</source>
        <translation>许多人贡献了翻译。</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="88"/>
        <source>You can also help to translate SMTube into your own language.</source>
        <translation>你可以帮助我们将 SMTube 翻译成您的母语。</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="89"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>访问 %1 并加入翻译团队</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="91"/>
        <source>Click here to know the translators from the transifex teams</source>
        <translation>点击这里查看 transifex 翻译团队的成员</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
</context>
<context>
    <name>BrowserWindow</name>
    <message>
        <location filename="../browserwindow.cpp" line="112"/>
        <source>Home</source>
        <translation>主页</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="115"/>
        <source>Navigation</source>
        <translation>导航</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="123"/>
        <source>Zoom +</source>
        <translation>放大</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="127"/>
        <source>Zoom -</source>
        <translation>缩小</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="131"/>
        <source>&amp;Quit</source>
        <translation>退出(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="134"/>
        <source>&amp;Navigation</source>
        <translation>导航(&amp;N)</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="146"/>
        <source>&amp;View</source>
        <translation>视图(&amp;V)</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="147"/>
        <source>Toolbar</source>
        <translation>工具栏</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="151"/>
        <source>Statusbar</source>
        <translation>状态条</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="155"/>
        <source>&amp;Settings</source>
        <translation>设置(&amp;S)</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="163"/>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="167"/>
        <source>&amp;Update YouTube playback support</source>
        <translation>&amp;更新YouTube回放支持</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="169"/>
        <source>&amp;Install / Update YouTube playback support</source>
        <translation>&amp;安装/更新YouTube回放支持</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="175"/>
        <source>&amp;About SMTube</source>
        <translation>关于 SMTube (&amp;A)</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="296"/>
        <source>Download video using an external service</source>
        <translation>使用外置服务下载视频</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="297"/>
        <source>Download</source>
        <translation>下载</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="524"/>
        <source>No video found</source>
        <translation>未找到视频</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="525"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>不过也不是没有办法获取此视频的URL。</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="282"/>
        <source>Loading... %1%</source>
        <translation>加载... %1%</translation>
    </message>
</context>
<context>
    <name>CodeDownloader</name>
    <message>
        <location filename="../codedownloader.cpp" line="49"/>
        <source>Downloading...</source>
        <translation>下载中...</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="76"/>
        <source>Connecting to %1</source>
        <translation>正在连接到 1%</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="145"/>
        <source>The YouTube code has been installed successfully.</source>
        <translation>YouTube代码已经安装成功</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="146"/>
        <source>Installed version: %1</source>
        <translation>已安装版本: 1%</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="147"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <source>It&apos;s not possible to save %1.</source>
        <translation>无法保存 1%。</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="165"/>
        <source>%1 failed to communicate with youtube-dl. Either it&apos;s not installed or it doesn&apos;t work correctly.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="169"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation type="unfinished">不过也不是没有办法获取此视频的URL。</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="170"/>
        <source>Maybe you need to update youtube-dl.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="175"/>
        <location filename="../codedownloader.cpp" line="208"/>
        <source>In order to play YouTube videos, %1 needs an external application called youtube-dl.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="176"/>
        <source>This component needs to be updated frequently.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="177"/>
        <source>You can update it just by reinstalling SMPlayer. The installer will download and install the very latest version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="179"/>
        <source>Install / Update YouTube support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="209"/>
        <source>%1 can download and install this application for you.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="210"/>
        <source>It will be downloaded from the official website and installed in %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="211"/>
        <source>Would you like to proceeed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="215"/>
        <location filename="../codedownloader.cpp" line="218"/>
        <source>Install YouTube support?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="27"/>
        <source>&amp;General</source>
        <translation>常规(&amp;G)</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="127"/>
        <source>A&amp;dd...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="166"/>
        <source>&amp;Players</source>
        <translation>播放器(&amp;P)</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="214"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="179"/>
        <source>Up</source>
        <translation>向上</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="33"/>
        <source>Playback</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="39"/>
        <source>Preferred &amp;quality:</source>
        <translation>偏好质量(&amp;Q):</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="94"/>
        <source>Sites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="100"/>
        <source>&amp;Site:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="120"/>
        <source>Edi&amp;t...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="138"/>
        <source>De&amp;lete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="225"/>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="249"/>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="262"/>
        <source>A&amp;dd predefined players</source>
        <translation>增加预定义的播放器</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="298"/>
        <source>&amp;Interface</source>
        <translation>界面(&amp;I)</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="306"/>
        <source>&amp;Style:</source>
        <translation>样式(&amp;S):</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="342"/>
        <source>Font:</source>
        <translation>字体:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="356"/>
        <source>C&amp;hange...</source>
        <translation>更改(&amp;H)...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="68"/>
        <source>Download</source>
        <translation>下载</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="74"/>
        <source>Download videos using an &amp;external service</source>
        <translation>使用外置服务下载视频(&amp;E)</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="190"/>
        <source>Down</source>
        <translation>向下</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="79"/>
        <source>Default</source>
        <translation>默认</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="56"/>
        <source>Click to select a file or folder</source>
        <translation>点击选择一个文件或文件夹</translation>
    </message>
</context>
<context>
    <name>MyWebView</name>
    <message>
        <location filename="../mywebview.cpp" line="37"/>
        <source>Open in &amp;YouTube</source>
        <translation>在 &amp;YouTube 中打开</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="48"/>
        <source>&amp;Save link...</source>
        <translation>保存链接(&amp;S)...</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="51"/>
        <source>Copy &amp;link to clipboard</source>
        <translation>复制链接到剪贴板(&amp;l)</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="52"/>
        <source>Open link in this window</source>
        <translation>在此窗口中打开链接</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="54"/>
        <source>&amp;Copy text to clipboard</source>
        <translation>复制文字到剪贴板(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="55"/>
        <source>Open link in &amp;new window</source>
        <translation>在新窗口中打开链接(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="79"/>
        <source>&amp;Play with</source>
        <translation>使用此设备播放(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="84"/>
        <source>Play &amp;audio with</source>
        <translation>使用此设备播放音频(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="137"/>
        <source>&amp;Play with %1</source>
        <translation>使用 %1 播放(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="144"/>
        <source>Play &amp;audio with %1</source>
        <translation>使用 1% 播放音频(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="151"/>
        <source>Play video with a &amp;web browser</source>
        <translation>使用网页浏览器播放视频(&amp;W)</translation>
    </message>
</context>
<context>
    <name>PlayerDialog</name>
    <message>
        <location filename="../playerdialog.ui" line="14"/>
        <source>Edit Player</source>
        <translation>编辑播放器</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>名称(&amp;N):</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="39"/>
        <source>&amp;Executable:</source>
        <translation>可执行文件(&amp;E):</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="56"/>
        <source>&amp;Parameters:</source>
        <translation>参数(&amp;P):</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="71"/>
        <source>This player supports &amp;video sites</source>
        <translation>此播放器支持播放视频网站的视频(&amp;V)</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="78"/>
        <source>This player can play &amp;online TV</source>
        <translation>此播放器可以播放在线电视(&amp;O)</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="87"/>
        <source>Preferred &amp;quality:</source>
        <translation>画质优先(&amp;Q):</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="117"/>
        <source>Add to &amp;menu:</source>
        <translation>添加到菜单(&amp;M):</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="28"/>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="29"/>
        <source>Video</source>
        <translation>视频</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="30"/>
        <source>Audio</source>
        <translation>音频</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="31"/>
        <source>Video and audio</source>
        <translation>视频及音频</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="33"/>
        <source>Default</source>
        <translation>默认</translation>
    </message>
</context>
<context>
    <name>SiteDialog</name>
    <message>
        <location filename="../sitedialog.ui" line="14"/>
        <source>Edit Site</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation type="unfinished">名称(&amp;N):</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="39"/>
        <source>&amp;Home page URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="56"/>
        <source>&amp;Search URL:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
